pub enum CompiledNessaExpr {
Show 56 variants Empty, Bool(bool), Int(Integer), Float(f64), Str(String), Array(usize, Type), Lambda(usize, Type, Type), Construct(usize, usize, Vec<Type>), Attribute(usize), AttributeRef(usize), AttributeMut(usize), Tuple(usize), StoreVariable(usize), GetVariable(usize), Drop, Jump(usize), RelativeJump(i32), RelativeJumpIfFalse(usize, bool), RelativeJumpIfTrue(usize, bool), Call(usize), Return, NativeFunctionCall(usize, usize, Vec<Type>), UnaryOperatorCall(usize, usize, Vec<Type>), BinaryOperatorCall(usize, usize, Vec<Type>), NaryOperatorCall(usize, usize, Vec<Type>), Copy, Deref, ToFloat, Addi, Addf, Subi, Subf, Muli, Mulf, Divi, Divf, Modi, Modf, Negi, Negf, Lti, Ltf, Gti, Gtf, Lteqi, Lteqf, Gteqi, Gteqf, Eqi, Eqf, Neqi, Neqf, Not, Or, And, Halt,
}

Variants



Empty



Bool(bool)



Int(Integer)



Float(f64)



Str(String)



Array(usize, Type)



Lambda(usize, Type, Type)



Construct(usize, usize, Vec<Type>)



Attribute(usize)



AttributeRef(usize)



AttributeMut(usize)



Tuple(usize)



StoreVariable(usize)



GetVariable(usize)



Drop



Jump(usize)



RelativeJump(i32)



RelativeJumpIfFalse(usize, bool)



RelativeJumpIfTrue(usize, bool)



Call(usize)



Return



NativeFunctionCall(usize, usize, Vec<Type>)



UnaryOperatorCall(usize, usize, Vec<Type>)



BinaryOperatorCall(usize, usize, Vec<Type>)



NaryOperatorCall(usize, usize, Vec<Type>)



Copy



Deref



ToFloat



Addi



Addf



Subi



Subf



Muli



Mulf



Divi



Divf



Modi



Modf



Negi



Negf



Lti



Ltf



Gti



Gtf



Lteqi



Lteqf



Gteqi



Gteqf



Eqi



Eqf



Neqi



Neqf



Not



Or



And



Halt

Implementations

source

impl CompiledNessaExpr

source

pub fn needs_float(&self) -> bool

source

pub fn needs_deref(&self) -> bool

source

pub fn to_string(&self, ctx: &NessaContext) -> String